@@ -47,7 +47,7 @@ DGPA <- function(Data, Group, ncomp=NULL, Scale=FALSE, graph=FALSE){
   #=========================================================================
   #                              2. preparing Data
   #=========================================================================
-  if (class(Data) == 'data.frame') {
+  if (is.data.frame(Data) == TRUE) {
     Data=as.matrix(Data)
   }
   if(is.null(ncomp)) {ncomp=2}  # or H=qr(g_data_group)$rank
