@@ -50,7 +50,7 @@ DSTATIS <- function(Data, Group, ncomp=NULL, Scale=FALSE, graph=FALSE){
   #=========================================================================
   #                              2. preparing Data
   #=========================================================================
-  if (class(Data) == 'data.frame') {
+  if (is.data.frame(Data) == TRUE) {
     Data=as.matrix(Data)
   }
   if(is.null(ncomp)) {ncomp=2}  
